OC.L10N.register(
    "tasks",
    {
    "Tasks" : "งาน",
    "Important" : "สำคัญ",
    "Today" : "วันนี้",
    "Week" : "สัปดาห์",
    "All" : "ทั้งหมด",
    "Current" : "ปัจจุบัน",
    "Completed" : "เสร็จสมบูรณ์",
    "Delete" : "ลบ",
    "Cancel" : "ยกเลิก",
    "Change sort order" : "เปลี่ยนการเรียงลำดับ",
    "Default" : "ค่าเริ่มต้น",
    "Due date" : "วันที่ครบกำหนด",
    "Start date" : "วันที่เริ่มต้น",
    "Priority" : "ลำดับความสำคัญ",
    "Manually" : "ทำด้วยตนเอง",
    "Alphabetically" : "เรียงตามตัวอักษร",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n งานเสร็จสมบูรณ์"],
    "Tomorrow" : "วันพรุ่งนี้",
    "Set start date" : "วันที่เริ่มต้นการตั้งค่า",
    "Set due date" : "ระบุวันครบกำหนด",
    "Task not found!" : "ไม่พบงาน!",
    "Edit" : "แก้ไข",
    "Download" : "ดาวน์โหลด",
    "Save" : "บันทึก",
    "New List" : "รายชื่อใหม่",
    "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
    "Settings" : "ตั้งค่า",
    "Visibility of Smart Collections" : "การแสดงผลของสมาร์ทคอลเลกชัน",
    "Hidden" : "ซ่อน",
    "Visible" : "มองเห็นได้",
    "Automatic" : "อัตโนมัติ"
},
"nplurals=1; plural=0;");
